import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

/*
 * Created on Feb 8, 2004
 * This demonstrates simple streams.
 * It reads a file of CSV data and prints it
 */

/**
 * @author Kent
 */
public class files1 {
	private final static int NUMFIELDS = 10;  // number of pieces in input
	
	// this takes a csv string and splits it into NUMFIELDS pieces
	// each piece is stored in a slot in the string array d
	public static void splitter(String s, String [] d)
	{
		int index=0, end = 0;
		for(int i=0; i < NUMFIELDS; i++) {
			// find the next seperator, starting at position index
			end = s.indexOf(',', index);
			// the next piece is from index to end
			if(end == -1)  // separator not found, last piece
				d[i] = s.substring(index);  // copy rest of string
			else
				d[i] = s.substring(index,end); // pull out the piece
			index = end + 1; // skip past the seperator
		} // for
	} // splitter
	
	public static void main(String[] args) {
		// first we create an object to represent the file
		// and do some tests on it
		File infile = new File("source.csv"); 
		if(! infile.exists()) {
			System.out.println("The file " + infile.getName() + " was not found");
			System.exit(1);
		}
		if(! infile.canRead()) {
			System.out.println("The file " + infile.getName() + " cannot be read");
			System.exit(1);
		}
		
		String csvlinein;
		String[] data = new String[NUMFIELDS];
		try {
			// Now we create a basic file reader to read from the
			// file object
			FileReader instream = new FileReader(infile);
			// Next we need to add some buffering to the stream to be able to
			// read it in bigger junks
			BufferedReader buffin = new BufferedReader(instream);
			
			// read each line from the input file and process it
			// readLine() returns a string from the input stream.
			// If there is no data, it returns null
			while( (csvlinein = buffin.readLine()) != null) {
				// There are 10 fields on each line
				// we have to break the string into 10 parts and
				// put each one in a slot in a string array			
				splitter(csvlinein,data);  // csv string parser
				
				// now print them with the field names
				//	Last,First,Role,Tag,Auto,Where,When,Title,pub,iss
				System.out.println("Last Name: " + data[0]);
				System.out.println("First Name: " + data[1]);
				System.out.println("Role: " + data[2]);
				System.out.println("Tag: " + data[3]);
				System.out.println("Autographed: " + data[4]);
				System.out.println("Where: " + data[5]);
				System.out.println("When: " + data[6]);
				System.out.println("Title: " + data[7]);
				System.out.println("Publisher: " + data[8]);
				System.out.println("Issue: " + data[9]);		
			} // while reading
		}  catch(FileNotFoundException f) {
			System.out.println("The file was not found");
			System.out.println("Details: " + f.getMessage());
			System.exit(1);
		}
		catch(IOException i) {
			System.out.println("There was an IO problem");
			System.out.println("Details: " + i.getMessage());
			System.exit(1);
		}
	}  // main
} // files1
