import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;

/*
 * Created on Feb 8, 2004
 * This demonstrates simple streams.
 * It reads a file of CSV data and create as new file as XML
 */

/**
 * @author Kent
 */
public class files2 {
	private final static int NUMFIELDS = 10;  // number of pieces in input
	private static String[]labels = new String[NUMFIELDS];
	private final static String labeldata = 
"LastName,FirstName,Role,Tag,Autographed,Where,When,Title,Publisher,Issue";
	
	// this takes a csv string and splits it into NUMFIELDS pieces
	// each piece is stored in a slot in the string array d
	public static void splitter(String s, String [] d)
	{
		int index=0, end = 0;
		for(int i=0; i < NUMFIELDS; i++) {
			// find the next seperator, starting at position index
			end = s.indexOf(',', index);
			// the next piece is from index to end
			if(end == -1)  // separator not found, last piece
				d[i] = s.substring(index);  // copy rest of string
			else
				d[i] = s.substring(index,end); // pull out the piece
			index = end + 1; // skip past the seperator
		} // for
	} // splitter
	
	/*
	 * Write out the data in the string array s as XML to the
	 * output stream o
	 */
	private static void toxml(PrintWriter o, String[] s)
	{
		o.println("<signed>");  // record header tag
		for(int i=0; i< NUMFIELDS; i++) {
			o.print("<" + labels[i] + ">");  // data tag
			o.print(s[i]);  // data
			o.println("</" + labels[i] + ">");  // data close tag
		} // for
		o.println("</signed>");  // record end tag
	} //  toxml
	
	public static void main(String[] args) {
		// first we create an object to represent the file
		// and do some tests on it
		BufferedReader buffin=null;  // input stream
		PrintWriter buffout=null;    // output stream
		String csvlinein;
		
		String[] data = new String[NUMFIELDS];
		// make an array of the label names
		splitter(labeldata,labels);
		
		try {
			// in this version, we create the whole set
			// of file objects in one step
			// we lose the check on the file existence
			// and readability, but if these done't work,
			// an exception will be thrown
			buffin = new BufferedReader(
										new FileReader(
											new File("source.csv")
										)
			);
			
			// do the same thing to create the output file
			buffout = new PrintWriter(
												new FileOutputStream(
													new File("source.xml")
												)
						);
			
			// read each line from the input file and process it
			// readLine() returns a string from the input stream.
			// If there is no data, it returns null
			// need to write out XML doc header here
			buffout.println("<signedrecords>");
			while( (csvlinein = buffin.readLine()) != null) {
				// There are 10 fields on each line
				// we have to break the string into 10 parts and
				// put each one in a slot in a string array			
				splitter(csvlinein,data);  // csv string parser
				
				// convert to XML and write to file
				toxml(buffout,data);
				
			} // while reading
			buffout.println("</signedrecords>");
			buffin.close();  // close the input file
		}  catch(FileNotFoundException f) {
			System.out.println("The file was not found");
			System.out.println("Details: " + f.getMessage());
			System.exit(1);
		}
		catch(IOException i) {
			System.out.println("There was an IO problem");
			System.out.println("Details: " + i.getMessage());
			System.exit(1);
		}
		finally {
			buffout.close();  // close the output file
		}
	}  // main
} // files2
