import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.border.*;

/**
 * This is a simple demo of events and such
 * 
 * @author Kent Archie
 * @version 1.0
 */
public class RunButton extends JFrame
{
    private JLabel title;   // title at top of display
    private JLabel status;  // current value of the button counter
    private JButton click;  // the button to press
    private JPanel upper;   // holds the title and status
    private JPanel appPanel; // holds the whole display
    private int count=0;     // how many times has the button been pressed

    /**
     * Constructor for objects of class RunButton
     */
    public RunButton()
    {
        super("Button Example"); // set frame title
        setSize(400,300);      // set frame size
        setVisible(true);   // make sure we can see it

		// create the title widget, tell it to put the message string
		// center and specify the font
        title = new JLabel ("Button Test", SwingConstants.CENTER);
        title.setFont (new Font ("Serif", Font.PLAIN, 12));

		// create the button that does the work
        click = new JButton("Press me");
        
		// this label will be updated to reflect the count
        status = new JLabel("Hello",SwingConstants.CENTER); // nothing there to start

		// Create a panel container to hold the two labels
		//  and put the two labels in the panel;
		//  This will go in the upper part of the frame.
        upper = new JPanel();  
//        upper.setBorder(new TitledBorder( new EtchedBorder(),"Top Panel"));

        upper.setLayout(new FlowLayout());
        upper.add(title); upper.add(status);
    
        // this holds the whole display
        appPanel = new JPanel();   
//        appPanel.setBorder(new TitledBorder( new EtchedBorder(),"Main Panel"));
        appPanel.setLayout(new BorderLayout());
        appPanel.add( upper,BorderLayout.NORTH);
        appPanel.add( click, BorderLayout.SOUTH);

        setContentPane(appPanel);  // put in the main display area
        
        // set up the event handler for the button
        click.addActionListener(new ButtonListener());

    } // RunButton constructor

    // inner class to handle events
    private class ButtonListener implements ActionListener
    {
        public void actionPerformed(ActionEvent event)
        {
            Object source = event.getSource();  // who sent the action?
            if(source == click) {  // was it the button?
				// update the counter and then the status label
				// the message depends on the number of times the
				// button was clicked
                count++;
                if(count <= 1)
                    status.setText("The button was pressed once");
                else
                    status.setText("The button was pressed " + count + " times");
            }
            else   // wasn't our button
                status.setText("Something else happened");
        } // actionPerformed
    } // class ButtonListener
} // class RunButton
