/**
 * This represents a flashlight
 * 
 * @author Kent Archie
 * @version 1.0
 */
public class Light
{
    private final int DEFAULTBATTS=2;
    private Bulb bulb;
    private Switch toggle;
    private Wires connection;
    private Battery[] battery;
    private int numbatts;  // how many batteries
    private int battype;  // what kind are they

    /**
     * This is a multi-argument constructor
     * 
     * @param  bulbtype Bulb type
     * @param  connect Wire type
     * @param  switchtype  Switch type
     * @param  nbatts Number of batteries
     * @param  batts  Kind of battery
     */
    public Light(int bulbtype, int connect, int switchtype, int nbatts, int type)
    {
        numbatts = nbatts;
        battype = type;
        bulb = new Bulb(bulbtype);
        connection = new Wires(connect);
        toggle = new Switch(switchtype);
        changeBatteries();
    } // Light

    /**
     * Constructor for objects of class Light
     */
    public Light()
    {
        numbatts = DEFAULTBATTS;
        bulb = new Bulb(Bulb.TUNGSTEN);
        connection = new Wires(Wires.COPPER);
        toggle = new Switch(Switch.SLIDE);
        changeBatteries();
    } // Light

    /** toggle the light switch */
    public boolean pressSwitch()
    {
        toggle.toggle();
		if(! bulb.checkBulb(10)) {
			System.out.println("Bulb Failed");
			return false;
		}
		if(! connection.checkWires()) {
			System.out.println("Wires Failed");
			return false;
		}
        for(int i=0; i < numbatts; i++) {
            battery[i].adjustpower();
			if(battery[i].getPower() <= 0.0) {
				System.out.println("Battery " + i + " Failed");
				return false;
			}
		} // for
		return true;
    } // pressSwitch

    /** replace the batteries with new ones of the same type
        also used to intially put batteries in
        The GC takes care of the old one
     */
    public void changeBatteries()
    {
        battery = new Battery[numbatts];
        for(int i=0; i < numbatts; i++)
            battery[i] = new Battery(battype);
    } // changeBatteries

    /** return string form of the Light type */
    public String toString()
    {
        return( "The bulb type is " + bulb
                + "\nthe switch type is " + toggle
                + "\nthe wire type is " + connection
                + "\nthere are " + numbatts + " "
                + battery[0] + " batteries \nit is "
                + toggle.statusString());
    } // toString
} // Light
